@@ -2,11 +2,21 @@
 #define PYTHONIC_INCLUDE_NUMPY_CONJUGATE_HPP
 
 #include "pythonic/include/types/numpy_op_helper.hpp"
-#include "pythonic/include/utils/numpy_traits.hpp"
 #include "pythonic/include/utils/functor.hpp"
+#include "pythonic/include/utils/numpy_traits.hpp"
 
 #include <xsimd/xsimd.hpp>
 
+// Inject some extra symbol in xsimd namespace, until that's fixed upstream
+#if XSIMD_VERSION_MAJOR < 8 ||                                                 \
+    (XSIMD_VERSION_MAJOR == 8 && XSIMD_VERSION_MINOR == 0 &&                   \
+     XSIMD_VERSION_PATCH <= 5)
+namespace xsimd
+{
+  using std::conj;
+}
+#endif
+
 PYTHONIC_NS_BEGIN
 
 namespace numpy
@@ -34,11 +44,11 @@ namespace numpy
     {
       return v;
     }
-  }
+  } // namespace wrapper
 #define NUMPY_NARY_FUNC_NAME conjugate
 #define NUMPY_NARY_FUNC_SYM wrapper::conjugate
 #include "pythonic/include/types/numpy_nary_expr.hpp"
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
